==> h5p-7.x-1.19.tar.gz: h5p/modules/h5peditor/h5peditor/language/es.js <==
H5PEditor.language.core = {
  missingTranslation: '[Falta la traducción :key]',
  loading: 'Cargando :type, por favor espera...',
  selectLibrary: 'Selecciona la librería que quieres usar con tu contenido.',
  unknownFieldPath: 'No se puede encontrar ":path".',
  notImageField: '":path" no es una imagen.',
  notImageOrDimensionsField: '":path" no es una imagen o un campo de dimensiones.',
  requiredProperty: 'La :property es requerida y debe tener un valor.',
  onlyNumbers: 'El valor de :property solo puede contener números.',
  exceedsMax: 'El valor de :property excede el máximo de :max.',
  belowMin: 'El valor de :property excede el mínimo de :min.',
  outOfStep: 'El valor de :property solo puede ser cambiado en pasos de :step.',
  addFile: 'Añadir archivo',
  removeFile: 'Eliminar archivo',
  changeLibrary: 'Cambiar el tipo de contenido',
  confirmRemoval: '¿Estás seguro de que quieres eliminar este :type?',
  removeImage: 'Eliminar imagen',
  confirmImageRemoval: 'Esto eliminará la imagen. ¿Seguro que desea continuar?',
  changeFile: 'Cambiar archivo',
  semanticsError: 'Error en semantics: :error',
  missingProperty: 'El campo :index no contiene la propiedad :property.',
  expandCollapse: 'Expandir/Colapsar',
  addEntity: 'Añadir :entity',
  tooLong: 'El valor del campo es demasiado largo, debería contener un máximo de :max lettras.',
  invalidFormat: 'El valor del campo contiene un formato no válido o caracteres prohibidos.',
  confirmChangeLibrary: 'Al hacer esto perderás todo el trabajo realizado con el tipo de contenido actual. ¿Estás seguro de que quieres cambiar el tipo de contenido?',
  moreLibraries: 'Accede a <a href="http://h5p.org/content-types-and-applications" target="_blank">más tipos de contenido</a> en h5p.org',
  commonFields: 'Parámetros y textos',
  commonFieldsDescription: 'Aquí puedes editar parámetros o traducir textos utilizados en este contenido.',
  uploading: 'Subiendo, por favor espera...',
  noFollow: 'No se puede seguir el campo ":path".',
  editCopyright: 'Editar copyright',
  close: 'Cerrar',
  tutorialAvailable: 'Tutorial disponible',
  editMode: 'Modo de edición',
  listLabel: 'Lista',
  uploadError: 'Error en la subida del archivo',
  fileToLarge: 'El archivo que intentas subir es demasiado grande.',
  noSemantics: 'Error, no se ha podido cargar el formulario del tipo de contenido.',
  editImage: 'Edit image',
  saveLabel: 'Save',
  cancelLabel: 'Cancel',
  resetToOriginalLabel: 'Reset to original',
  loadingImageEditor: 'Loading image editor, please wait...',
  selectFiletoUpload: 'Select file to upload',
  or: 'or',
  enterAudioUrl: 'Enter audio source URL',
  enterVideoUrl: 'Enter video source URL or YouTube link',
  addVideoDescription: 'H5P supports all external video sources formatted as mp4, webm or ogv, like Vimeo Pro, and has support for YouTube links.',
  insert: 'Insert',
  cancel: 'Cancel',
  height: 'height',
  width: 'width',
  textField: 'text field',
  numberField: 'number field'
};

==> h5p-7.x-1.26.tar.gz: h5p/modules/h5peditor/h5peditor/language/es.js <==
H5PEditor.language.core = {
  missingTranslation: '[Falta la traducción :key]',
  loading: 'Cargando, por favor espera...',
  selectLibrary: 'Selecciona la librería que quieres usar con tu contenido.',
  unknownFieldPath: 'No se puede encontrar ":path".',
  notImageField: '":path" no es una imagen.',
  notImageOrDimensionsField: '":path" no es una imagen o un campo de dimensiones.',
  requiredProperty: 'La :property es requerida y debe tener un valor.',
  onlyNumbers: 'El valor de :property solo puede contener números.',
  exceedsMax: 'El valor de :property excede el máximo de :max.',
  listExceedsMax: 'The list exceeds the maximum of :max items.',
  belowMin: 'El valor de :property excede el mínimo de :min.',
  listBelowMin: 'The list needs at least :min items for the content to function properly.',
  outOfStep: 'El valor de :property solo puede ser cambiado en pasos de :step.',
  add: 'Add',
  addFile: 'Añadir archivo',
  removeFile: 'Eliminar archivo',
  confirmRemoval: '¿Estás seguro de que quieres eliminar este :type?',
  removeImage: 'Eliminar imagen',
  confirmImageRemoval: 'Esto eliminará la imagen. ¿Seguro que desea continuar?',
  changeFile: 'Cambiar archivo',
  changeLibrary: 'Cambiar el tipo de contenido',
  semanticsError: 'Error en semantics: :error',
  missingProperty: 'El campo :index no contiene la propiedad :property.',
  expandCollapse: 'Expandir/Colapsar',
  addEntity: 'Añadir :entity',
  tooLong: 'El valor del campo es demasiado largo, debería contener un máximo de :max lettras.',
  invalidFormat: 'El valor del campo contiene un formato no válido o caracteres prohibidos.',
  confirmChangeLibrary: 'Al hacer esto perderás todo el trabajo realizado con el tipo de contenido actual. ¿Estás seguro de que quieres cambiar el tipo de contenido?',
  moreLibraries: 'Accede a <a href="http://h5p.org/content-types-and-applications" target="_blank">más tipos de contenido</a> en h5p.org',
  commonFields: 'Parámetros y textos',
  commonFieldsDescription: 'Aquí puedes editar parámetros o traducir textos utilizados en este contenido.',
  uploading: 'Subiendo, por favor espera...',
  noFollow: 'No se puede seguir el campo ":path".',
  editCopyright: 'Editar copyright',
  close: 'Cerrar',
  tutorialAvailable: 'Tutorial disponible',
  editMode: 'Modo de edición',
  listLabel: 'Lista',
  uploadError: 'Error en la subida del archivo',
  fileToLarge: 'El archivo que intentas subir es demasiado grande.',
  unknownFileUploadError: 'Unknown file upload error',
  noSemantics: 'Error, no se ha podido cargar el formulario del tipo de contenido.',
  editImage: 'Edit image',
  saveLabel: 'Save',
  cancelLabel: 'Cancel',
  resetToOriginalLabel: 'Reset to original',
  loadingImageEditor: 'Loading image editor, please wait...',
  selectFiletoUpload: 'Select file to upload',
  or: 'or',
  enterAudioUrl: 'Enter audio source URL',
  enterVideoUrl: 'Enter video source URL or YouTube link',
  addVideoDescription: 'H5P supports all external video sources formatted as mp4, webm or ogv, like Vimeo Pro, and has support for YouTube links.',
  insert: 'Insert',
  cancel: 'Cancel',
  height: 'height',
  width: 'width',
  textField: 'text field',
  numberField: 'number field',
  orderItemUp: 'Order item up',
  orderItemDown: 'Order item down',
  removeItem: 'Remove item'
};
